@@ -1,7 +1,7 @@
 package TestApp;
 
 use strict;
-use Catalyst qw/-Debug/;
+use Catalyst;
 
 our $VERSION = '0.01';
 
